==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTCAPACITYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour EQUIPMENTCAPACITYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTCAPACITYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAPACITYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEEFFECTIVE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTCAPACITYID_Type", propOrder = {
    "capacitycode",
    "equipmentid",
    "dateeffective"
})
public class EQUIPMENTCAPACITYID_Type {

    @XmlElement(name = "CAPACITYCODE", required = true)
    protected USERDEFINEDCODEID_Type capacitycode;
    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "DATEEFFECTIVE", required = true)
    protected DATETIME dateeffective;

    /**
     * Obtient la valeur de la propriété capacitycode.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getCAPACITYCODE() {
        return capacitycode;
    }

    /**
     * Définit la valeur de la propriété capacitycode.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setCAPACITYCODE(USERDEFINEDCODEID_Type value) {
        this.capacitycode = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Définit la valeur de la propriété equipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété dateeffective.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEEFFECTIVE() {
        return dateeffective;
    }

    /**
     * Définit la valeur de la propriété dateeffective.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEEFFECTIVE(DATETIME value) {
        this.dateeffective = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTCAPACITYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for EQUIPMENTCAPACITYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTCAPACITYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAPACITYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEEFFECTIVE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTCAPACITYID_Type", propOrder = {
    "capacitycode",
    "equipmentid",
    "dateeffective"
})
public class EQUIPMENTCAPACITYID_Type {

    @XmlElement(name = "CAPACITYCODE", required = true)
    protected USERDEFINEDCODEID_Type capacitycode;
    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "DATEEFFECTIVE", required = true)
    protected DATETIME dateeffective;

    /**
     * Gets the value of the capacitycode property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getCAPACITYCODE() {
        return capacitycode;
    }

    /**
     * Sets the value of the capacitycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setCAPACITYCODE(USERDEFINEDCODEID_Type value) {
        this.capacitycode = value;
    }

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the dateeffective property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEEFFECTIVE() {
        return dateeffective;
    }

    /**
     * Sets the value of the dateeffective property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEEFFECTIVE(DATETIME value) {
        this.dateeffective = value;
    }

}
